@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 from PyQt5.QtGui import QIcon
-from PyQt5.QtWidgets import QApplication
+from PyQt5.QtWidgets import QApplication, QMessageBox
 from jdTextEdit.gui.MainWindow import MainWindow
 from jdTextEdit.Enviroment import Enviroment
 from jdTextEdit.gui.CloseSaveWindow import CloseSaveWindow
@@ -56,22 +56,30 @@ def main():
     env.editCommandsWindow = EditCommandsWindow(env)
     env.dayTipWindow = DayTipWindow(env)
     env.aboutWindow = AboutWindow(env)
-    if env.settings.loadPlugins and not env.args["disablePlugins"]:
+    if env.settings.get("loadPlugins") and not env.args["disablePlugins"]:
         loadPlugins(os.path.join(env.programDir,"plugins"),env)
         loadPlugins(os.path.join(env.dataDir,"plugins"),env)
 
-    env.dockWidgtes.append([NotesWidget(env),env.translate("sidebar.notes"),"notes"])
-    env.dockWidgtes.append([TabListWidget(env),env.translate("sidebar.tabs"),"tablist"])
-    env.dockWidgtes.append([FileTreeWidget(env),env.translate("sidebar.files"),"files"])
-    env.dockWidgtes.append([ClipboardWidget(env),env.translate("sidebar.clipboard"),"clipboard"])
-    env.dockWidgtes.append([CharacterMapWidget(env),env.translate("sidebar.charactermap"),"charactermap"])
+    env.pluginAPI.addSidebarWidget(NotesWidget(env))
+    env.pluginAPI.addSidebarWidget(TabListWidget(env))
+    env.pluginAPI.addSidebarWidget(FileTreeWidget(env))
+    env.pluginAPI.addSidebarWidget(ClipboardWidget(env))
+    env.pluginAPI.addSidebarWidget(CharacterMapWidget(env))
 
-    if os.path.isfile(os.path.join(env.dataDir,"userChrome.css")):
+    if os.path.isfile(os.path.join(env.dataDir,"userChrome.css")) and env.settings.get("enableUserChrome"):
         f = open(os.path.join(env.dataDir,"userChrome.css"),"r",encoding="utf-8")
         app.setStyleSheet(f.read())
         f.close()
 
     app.setWindowIcon(QIcon(os.path.join(env.programDir,"Logo.png")))
 
+    # Ask for automatic updates on first run
+    if env.firstRun and env.enableUpdater:
+        answer = QMessageBox.question(env.mainWindow, env.translate("automaticUpdateSearch.title"), env.translate("automaticUpdateSearch.text"))
+        if answer == QMessageBox.Yes:
+            env.settings.searchUpdates = True
+        else:
+            env.settings.searchUpdates = False
+
     env.mainWindow.setup()
     sys.exit(app.exec())
